<!DOCTYPE html>
<html>
<head>
    <title>Constants Example</title>
</head>
<body>
    <h1>PHP Constants - Practical Examples</h1>
    <?php
    // Configuration Constants
    define("DATABASE_HOST", "localhost"); // Database server address
    define("DATABASE_USER", "myuser");      // Database username
    define("DATABASE_PASSWORD", "mypassword"); // Database password (In real app, store securely!)
    define("SITE_URL", "https://www.example.com"); // Base URL of the site

    // Application Logic Constants
    const MAX_FILE_SIZE = 2 * 1024 * 1024; // 2MB (in bytes) - Max upload size
    const ERROR_LOG_FILE = "/var/log/myapp/errors.log"; // Path to error log
    const ITEMS_PER_PAGE = 20; // Pagination: Number of items per page

    // Displaying Information (Less Generic)
    echo "<p>Connecting to database: " . DATABASE_HOST . " as user " . DATABASE_USER . "</p>";
    echo "<p>Website address: <a href='" . SITE_URL . "'>" . SITE_URL . "</a></p>";

    // Using Constants in Logic (More Realistic)
    $uploadedFileSize = 3 * 1024 * 1024; // Simulate an uploaded file size
    if ($uploadedFileSize > MAX_FILE_SIZE) {
        echo "<p style='color:red;'>Error: File too large. Maximum size is " . (MAX_FILE_SIZE / (1024 * 1024)) . " MB.</p>"; // Convert to MB for display
    }

    // Example of using a constant for pagination
    echo "<p>Displaying " . ITEMS_PER_PAGE . " items per page.</p>";

  

    ?>
    <p><strong>Explanation:</strong> Constants store values that shouldn't change, like database credentials, file paths, or application settings.  This makes code more readable, maintainable, and less prone to errors.  Using constants for things like file sizes or pagination limits makes it easy to adjust these values in one place.</p>
</body>
</html>