<!DOCTYPE html>
<html>
<head>
    <title>Functions Example</title>
</head>
<body>
    <h1>PHP Functions - Date Formatting</h1>
    <?php

    // Function to format a date in a user-friendly way
    function formatDate($timestamp, $format = "F j, Y") {  // Default format
        // Check if the timestamp is valid (an integer or numeric string)
        if (!is_numeric($timestamp)) {
            $timestamp = strtotime($timestamp); // Try to convert if it's a date string
            if ($timestamp === false) {
                return "Invalid date"; // Handle invalid input
            }
        }

        return date($format, $timestamp);
    }


    // Examples
    $today = time(); // Current timestamp
    echo "<p>Today's date (default): " . formatDate($today) . "</p>";
    echo "<p>Today's date (short): " . formatDate($today, "m/d/y") . "</p>"; // Custom format
    echo "<p>A specific date: " . formatDate("2024-03-15") . "</p>"; // From a date string
    echo "<p>Another date with time: " . formatDate("2024-03-15 10:30:00", "F j, Y g:i a") . "</p>"; // From a date string with time
    echo "<p>Invalid Date: " . formatDate("not a date") . "</p>"; // Show how the function handles invalid date input

    // Example using a past date
    $pastDate = strtotime("2 years ago");
    echo "<p>Two years ago: " . formatDate($pastDate) . "</p>";

    // Example of using the function in a loop to display dates for the next 7 days
    echo "<ul>";
    for ($i = 0; $i < 7; $i++) {
        $dateTimestamp = strtotime("+" . $i . " days");
        echo "<li>" . formatDate($dateTimestamp) . "</li>";
    }
    echo "</ul>";

    ?>

    <p><strong>Explanation:</strong> Functions group reusable code.  This <code>formatDate()</code> function takes a timestamp (or a date string) and an optional format string and returns a formatted date.  It handles invalid date input and allows you to easily change the date format throughout your website by modifying the function.  This is much more efficient and maintainable than writing the date formatting code repeatedly.</p>
</body>
</html>